@@ -16,14 +16,14 @@ class ReplayBufferEntry:
 
 
 @dataclass
-class HyperParams:
+class AgentParams:
     gamma: float = 0.99
     learn_every: int = 1
 
 
 @dataclass
-class DqnHyperParams(HyperParams):
-    lr: float = 0.01
+class DqnHyperParams(AgentParams):
+    lr: float = 0.0025
 
 
 @dataclass
@@ -42,7 +42,7 @@ class DoubleDuelingDqnHyperParams(DoubleDqnHyperParams):
 
 
 @dataclass
-class A2CHyperParams(HyperParams):
+class A2CHyperParams(AgentParams):
     lr: float = 0.001
 
 
@@ -67,7 +67,7 @@ TProgressCallback = T.Callable[[TrainingProgress], bool]
 @dataclass
 class TrainingParams:
     batch_size: int = 46
-    episodes: int = 500
+    episodes: int = 10000
 
 
 @dataclass
