@@ -8,6 +8,6 @@ from .dueling_dqn import DuelingDqnAgent
 class DoubleDuelingDqnAgent(DuelingDqnAgent, DoubleDqnAgent, ABC):
     def __init__(self,
                  action_space: int,
-                 hp: DoubleDuelingDqnHyperParams = DoubleDuelingDqnHyperParams(),
+                 agent_params: DoubleDuelingDqnHyperParams = DoubleDuelingDqnHyperParams(),
                  use_gpu: bool = True):
-        super(DoubleDuelingDqnAgent, self).__init__(action_space, hp, use_gpu)
+        super(DoubleDuelingDqnAgent, self).__init__(action_space, agent_params, use_gpu)
